"""The alias commands module.

These commands are used in the following models:
DPO4K, DPO4KB, MDO3, MDO3K, MDO4K, MDO4KB, MDO4KC, MSO4K, MSO4KB

THIS FILE IS AUTO-GENERATED, IT SHOULD NOT BE MANUALLY MODIFIED.

Please report an issue if one is found.

Commands and Queries:

::

    - ALIas:CATalog?
    - ALIas:DEFine <QString><,>{<QString>|<Block>}? <QString>
    - ALIas:DELEte:ALL
    - ALIas:DELEte:NAMe <QString>
    - ALIas:STATE {<NR1>|OFF|ON}
    - ALIas:STATE?
"""
from typing import Optional, TYPE_CHECKING

from .._helpers import SCPICmdRead, SCPICmdWrite, SCPICmdWriteNoArguments

if TYPE_CHECKING:
    from tm_devices.drivers.pi.pi_device import PIDevice


class AliasState(SCPICmdWrite, SCPICmdRead):
    """The ``ALIas:STATE`` command.

    **Description:**
        - Turns aliases on or off.

    **Usage:**
        - Using the ``.query()`` method will send the ``ALIas:STATE?`` query.
        - Using the ``.verify(value)`` method will send the ``ALIas:STATE?`` query and raise an
          AssertionError if the returned value does not match ``value``.
        - Using the ``.write(value)`` method will send the ``ALIas:STATE value`` command.

    **SCPI Syntax:**

    ::

        - ALIas:STATE {<NR1>|OFF|ON}
        - ALIas:STATE?

    **Info:**
        - ``OFF`` or <NR1> = 0 turns alias expansion off. If a defined alias is sent when
          ``ALIas:STATE`` is OFF, a command error (102) is generated.
        - ``ON`` or <NR1>0 turns alias expansion on. When a defined alias is received, the specified
          command sequence is substituted for the alias and executed.
    """


class AliasDeleteName(SCPICmdWrite):
    """The ``ALIas:DELEte:NAMe`` command.

    **Description:**
        - Removes a specified alias.

    **Usage:**
        - Using the ``.write(value)`` method will send the ``ALIas:DELEte:NAMe value`` command.

    **SCPI Syntax:**

    ::

        - ALIas:DELEte:NAMe <QString>

    **Info:**
        - ``<QString>`` is the name of the alias to remove. Using <QString> must be an existing
          alias.
    """

    _WRAP_ARG_WITH_QUOTES = True


class AliasDeleteAll(SCPICmdWriteNoArguments):
    """The ``ALIas:DELEte:ALL`` command.

    **Description:**
        - This command deletes all existing aliases.

    **Usage:**
        - Using the ``.write()`` method will send the ``ALIas:DELEte:ALL`` command.

    **SCPI Syntax:**

    ::

        - ALIas:DELEte:ALL
    """


class AliasDelete(SCPICmdRead):
    """The ``ALIas:DELEte`` command tree.

    **Usage:**
        - Using the ``.query()`` method will send the ``ALIas:DELEte?`` query.
        - Using the ``.verify(value)`` method will send the ``ALIas:DELEte?`` query and raise an
          AssertionError if the returned value does not match ``value``.

    Properties:
        - ``.all``: The ``ALIas:DELEte:ALL`` command.
        - ``.name``: The ``ALIas:DELEte:NAMe`` command.
    """

    def __init__(self, device: Optional["PIDevice"], cmd_syntax: str) -> None:
        super().__init__(device, cmd_syntax)
        self._all = AliasDeleteAll(device, f"{self._cmd_syntax}:ALL")
        self._name = AliasDeleteName(device, f"{self._cmd_syntax}:NAMe")

    @property
    def all(self) -> AliasDeleteAll:
        """Return the ``ALIas:DELEte:ALL`` command.

        **Description:**
            - This command deletes all existing aliases.

        **Usage:**
            - Using the ``.write()`` method will send the ``ALIas:DELEte:ALL`` command.

        **SCPI Syntax:**

        ::

            - ALIas:DELEte:ALL
        """
        return self._all

    @property
    def name(self) -> AliasDeleteName:
        """Return the ``ALIas:DELEte:NAMe`` command.

        **Description:**
            - Removes a specified alias.

        **Usage:**
            - Using the ``.write(value)`` method will send the ``ALIas:DELEte:NAMe value`` command.

        **SCPI Syntax:**

        ::

            - ALIas:DELEte:NAMe <QString>

        **Info:**
            - ``<QString>`` is the name of the alias to remove. Using <QString> must be an existing
              alias.
        """
        return self._name


class AliasDefine(SCPICmdWrite):
    """The ``ALIas:DEFine`` command.

    **Description:**
        - Assigns a sequence of program messages to an alias label. These messages are then
          substituted for the alias whenever it is received as a command or query, provided that
          ``ALIas:STATE`` has been turned on. The query form of this command returns the definitions
          of a selected alias.

    **Usage:**
        - Using the ``.write(value)`` method will send the ``ALIas:DEFine value`` command.

    **SCPI Syntax:**

    ::

        - ALIas:DEFine <QString><,>{<QString>|<Block>}? <QString>

    **Info:**
        - ``<QString>`` is the alias label.
        - ``<QString>`` or <Block> is a complete sequence of program messages.
    """


class AliasCatalog(SCPICmdRead):
    """The ``ALIas:CATalog`` command.

    **Description:**
        - This query-only command returns a list of the currently defined alias labels, separated by
          commas. If no aliases are defined, the query returns the string ''.

    **Usage:**
        - Using the ``.query()`` method will send the ``ALIas:CATalog?`` query.
        - Using the ``.verify(value)`` method will send the ``ALIas:CATalog?`` query and raise an
          AssertionError if the returned value does not match ``value``.

    **SCPI Syntax:**

    ::

        - ALIas:CATalog?
    """


class Alias(SCPICmdRead):
    """The ``ALIas`` command tree.

    **Usage:**
        - Using the ``.query()`` method will send the ``ALIas?`` query.
        - Using the ``.verify(value)`` method will send the ``ALIas?`` query and raise an
          AssertionError if the returned value does not match ``value``.

    Properties:
        - ``.catalog``: The ``ALIas:CATalog`` command.
        - ``.define``: The ``ALIas:DEFine`` command.
        - ``.delete``: The ``ALIas:DELEte`` command tree.
        - ``.state``: The ``ALIas:STATE`` command.
    """

    def __init__(self, device: Optional["PIDevice"] = None, cmd_syntax: str = "ALIas") -> None:
        super().__init__(device, cmd_syntax)
        self._catalog = AliasCatalog(device, f"{self._cmd_syntax}:CATalog")
        self._define = AliasDefine(device, f"{self._cmd_syntax}:DEFine")
        self._delete = AliasDelete(device, f"{self._cmd_syntax}:DELEte")
        self._state = AliasState(device, f"{self._cmd_syntax}:STATE")

    @property
    def catalog(self) -> AliasCatalog:
        """Return the ``ALIas:CATalog`` command.

        **Description:**
            - This query-only command returns a list of the currently defined alias labels,
              separated by commas. If no aliases are defined, the query returns the string ''.

        **Usage:**
            - Using the ``.query()`` method will send the ``ALIas:CATalog?`` query.
            - Using the ``.verify(value)`` method will send the ``ALIas:CATalog?`` query and raise
              an AssertionError if the returned value does not match ``value``.

        **SCPI Syntax:**

        ::

            - ALIas:CATalog?
        """
        return self._catalog

    @property
    def define(self) -> AliasDefine:
        """Return the ``ALIas:DEFine`` command.

        **Description:**
            - Assigns a sequence of program messages to an alias label. These messages are then
              substituted for the alias whenever it is received as a command or query, provided that
              ``ALIas:STATE`` has been turned on. The query form of this command returns the
              definitions of a selected alias.

        **Usage:**
            - Using the ``.write(value)`` method will send the ``ALIas:DEFine value`` command.

        **SCPI Syntax:**

        ::

            - ALIas:DEFine <QString><,>{<QString>|<Block>}? <QString>

        **Info:**
            - ``<QString>`` is the alias label.
            - ``<QString>`` or <Block> is a complete sequence of program messages.
        """
        return self._define

    @property
    def delete(self) -> AliasDelete:
        """Return the ``ALIas:DELEte`` command tree.

        **Usage:**
            - Using the ``.query()`` method will send the ``ALIas:DELEte?`` query.
            - Using the ``.verify(value)`` method will send the ``ALIas:DELEte?`` query and raise an
              AssertionError if the returned value does not match ``value``.

        Sub-properties:
            - ``.all``: The ``ALIas:DELEte:ALL`` command.
            - ``.name``: The ``ALIas:DELEte:NAMe`` command.
        """
        return self._delete

    @property
    def state(self) -> AliasState:
        """Return the ``ALIas:STATE`` command.

        **Description:**
            - Turns aliases on or off.

        **Usage:**
            - Using the ``.query()`` method will send the ``ALIas:STATE?`` query.
            - Using the ``.verify(value)`` method will send the ``ALIas:STATE?`` query and raise an
              AssertionError if the returned value does not match ``value``.
            - Using the ``.write(value)`` method will send the ``ALIas:STATE value`` command.

        **SCPI Syntax:**

        ::

            - ALIas:STATE {<NR1>|OFF|ON}
            - ALIas:STATE?

        **Info:**
            - ``OFF`` or <NR1> = 0 turns alias expansion off. If a defined alias is sent when
              ``ALIas:STATE`` is OFF, a command error (102) is generated.
            - ``ON`` or <NR1>0 turns alias expansion on. When a defined alias is received, the
              specified command sequence is substituted for the alias and executed.
        """
        return self._state



"""The connected commands module.

These commands are used in the following models:
LPD6, MSO2, MSO4, MSO4B, MSO5, MSO5B, MSO5LP, MSO6, MSO6B

THIS FILE IS AUTO-GENERATED, IT SHOULD NOT BE MANUALLY MODIFIED.

Please report an issue if one is found.

Commands and Queries:

::

    - CONNected:REQUested:STATus <NR1>
    - CONNected:STATus?
    - CONNected:USAGe:TRack:REQUested:STATus <NR1>
    - CONNected:USAGe:TRack:STATus?
"""
from typing import Optional, TYPE_CHECKING

from .._helpers import SCPICmdRead, SCPICmdWrite

if TYPE_CHECKING:
    from tm_devices.drivers.pi.pi_device import PIDevice


class ConnectedUsageTrackStatus(SCPICmdRead):
    """The ``CONNected:USAGe:TRack:STATus`` command.

    **Description:**
        - This query command returns the tracking usage status of the Connected Scope Preference
          feature. On the instrument, the feature is found in Utility > User Preferences > Other >
          Connected Scope Preferences.

    **Usage:**
        - Using the ``.query()`` method will send the ``CONNected:USAGe:TRack:STATus?`` query.
        - Using the ``.verify(value)`` method will send the ``CONNected:USAGe:TRack:STATus?`` query
          and raise an AssertionError if the returned value does not match ``value``.

    **SCPI Syntax:**

    ::

        - CONNected:USAGe:TRack:STATus?
    """


class ConnectedUsageTrackRequestedStatus(SCPICmdWrite):
    """The ``CONNected:USAGe:TRack:REQUested:STATus`` command.

    **Description:**
        - This command sets the tracking usage status of the Connected Scope Preference feature.
          After issuing the status command, the ``CONNected:SAVEPREferences`` command should be set
          immediately to make the feature enabled. On the instrument, the feature is found in
          Utility > User Preferences > Other > Connected Scope Preferences.

    **Usage:**
        - Using the ``.write(value)`` method will send the
          ``CONNected:USAGe:TRack:REQUested:STATus value`` command.

    **SCPI Syntax:**

    ::

        - CONNected:USAGe:TRack:REQUested:STATus <NR1>

    **Info:**
        - ``<NR1>`` enables or disables the Connected Scope Preference feature. The argument can be
          either 1 or 0. Setting 1 will enable the tracking usage status of the Connected Scope
          Preference feature.
    """


class ConnectedUsageTrackRequested(SCPICmdRead):
    """The ``CONNected:USAGe:TRack:REQUested`` command tree.

    **Usage:**
        - Using the ``.query()`` method will send the ``CONNected:USAGe:TRack:REQUested?`` query.
        - Using the ``.verify(value)`` method will send the ``CONNected:USAGe:TRack:REQUested?``
          query and raise an AssertionError if the returned value does not match ``value``.

    Properties:
        - ``.status``: The ``CONNected:USAGe:TRack:REQUested:STATus`` command.
    """

    def __init__(self, device: Optional["PIDevice"], cmd_syntax: str) -> None:
        super().__init__(device, cmd_syntax)
        self._status = ConnectedUsageTrackRequestedStatus(device, f"{self._cmd_syntax}:STATus")

    @property
    def status(self) -> ConnectedUsageTrackRequestedStatus:
        """Return the ``CONNected:USAGe:TRack:REQUested:STATus`` command.

        **Description:**
            - This command sets the tracking usage status of the Connected Scope Preference feature.
              After issuing the status command, the ``CONNected:SAVEPREferences`` command should be
              set immediately to make the feature enabled. On the instrument, the feature is found
              in Utility > User Preferences > Other > Connected Scope Preferences.

        **Usage:**
            - Using the ``.write(value)`` method will send the
              ``CONNected:USAGe:TRack:REQUested:STATus value`` command.

        **SCPI Syntax:**

        ::

            - CONNected:USAGe:TRack:REQUested:STATus <NR1>

        **Info:**
            - ``<NR1>`` enables or disables the Connected Scope Preference feature. The argument can
              be either 1 or 0. Setting 1 will enable the tracking usage status of the Connected
              Scope Preference feature.
        """
        return self._status


class ConnectedUsageTrack(SCPICmdRead):
    """The ``CONNected:USAGe:TRack`` command tree.

    **Usage:**
        - Using the ``.query()`` method will send the ``CONNected:USAGe:TRack?`` query.
        - Using the ``.verify(value)`` method will send the ``CONNected:USAGe:TRack?`` query and
          raise an AssertionError if the returned value does not match ``value``.

    Properties:
        - ``.requested``: The ``CONNected:USAGe:TRack:REQUested`` command tree.
        - ``.status``: The ``CONNected:USAGe:TRack:STATus`` command.
    """

    def __init__(self, device: Optional["PIDevice"], cmd_syntax: str) -> None:
        super().__init__(device, cmd_syntax)
        self._requested = ConnectedUsageTrackRequested(device, f"{self._cmd_syntax}:REQUested")
        self._status = ConnectedUsageTrackStatus(device, f"{self._cmd_syntax}:STATus")

    @property
    def requested(self) -> ConnectedUsageTrackRequested:
        """Return the ``CONNected:USAGe:TRack:REQUested`` command tree.

        **Usage:**
            - Using the ``.query()`` method will send the ``CONNected:USAGe:TRack:REQUested?``
              query.
            - Using the ``.verify(value)`` method will send the ``CONNected:USAGe:TRack:REQUested?``
              query and raise an AssertionError if the returned value does not match ``value``.

        Sub-properties:
            - ``.status``: The ``CONNected:USAGe:TRack:REQUested:STATus`` command.
        """
        return self._requested

    @property
    def status(self) -> ConnectedUsageTrackStatus:
        """Return the ``CONNected:USAGe:TRack:STATus`` command.

        **Description:**
            - This query command returns the tracking usage status of the Connected Scope Preference
              feature. On the instrument, the feature is found in Utility > User Preferences > Other
              > Connected Scope Preferences.

        **Usage:**
            - Using the ``.query()`` method will send the ``CONNected:USAGe:TRack:STATus?`` query.
            - Using the ``.verify(value)`` method will send the ``CONNected:USAGe:TRack:STATus?``
              query and raise an AssertionError if the returned value does not match ``value``.

        **SCPI Syntax:**

        ::

            - CONNected:USAGe:TRack:STATus?
        """
        return self._status


class ConnectedUsage(SCPICmdRead):
    """The ``CONNected:USAGe`` command tree.

    **Usage:**
        - Using the ``.query()`` method will send the ``CONNected:USAGe?`` query.
        - Using the ``.verify(value)`` method will send the ``CONNected:USAGe?`` query and raise an
          AssertionError if the returned value does not match ``value``.

    Properties:
        - ``.track``: The ``CONNected:USAGe:TRack`` command tree.
    """

    def __init__(self, device: Optional["PIDevice"], cmd_syntax: str) -> None:
        super().__init__(device, cmd_syntax)
        self._track = ConnectedUsageTrack(device, f"{self._cmd_syntax}:TRack")

    @property
    def track(self) -> ConnectedUsageTrack:
        """Return the ``CONNected:USAGe:TRack`` command tree.

        **Usage:**
            - Using the ``.query()`` method will send the ``CONNected:USAGe:TRack?`` query.
            - Using the ``.verify(value)`` method will send the ``CONNected:USAGe:TRack?`` query and
              raise an AssertionError if the returned value does not match ``value``.

        Sub-properties:
            - ``.requested``: The ``CONNected:USAGe:TRack:REQUested`` command tree.
            - ``.status``: The ``CONNected:USAGe:TRack:STATus`` command.
        """
        return self._track


class ConnectedStatus(SCPICmdRead):
    """The ``CONNected:STATus`` command.

    **Description:**
        - This query command returns the status of the Connected Scope Preference feature. On the
          instrument, the feature is found in Utility > User Preferences > Other > Connected Scope
          Preferences.

    **Usage:**
        - Using the ``.query()`` method will send the ``CONNected:STATus?`` query.
        - Using the ``.verify(value)`` method will send the ``CONNected:STATus?`` query and raise an
          AssertionError if the returned value does not match ``value``.

    **SCPI Syntax:**

    ::

        - CONNected:STATus?
    """


class ConnectedRequestedStatus(SCPICmdWrite):
    """The ``CONNected:REQUested:STATus`` command.

    **Description:**
        - This command sets the status of the Connected Scope Preference feature. After issuing the
          status command, the ``CONNected:SAVEPREferences`` command should be set immediately to
          make the feature enabled. On the instrument, the feature is found in Utility > User
          Preferences > Other > Connected Scope Preferences.

    **Usage:**
        - Using the ``.write(value)`` method will send the ``CONNected:REQUested:STATus value``
          command.

    **SCPI Syntax:**

    ::

        - CONNected:REQUested:STATus <NR1>

    **Info:**
        - ``<NR1>`` enables or disables the Connected Scope Preference feature. The argument can be
          either 1 or 0. Setting 1 will enable the feature.
    """


class ConnectedRequested(SCPICmdRead):
    """The ``CONNected:REQUested`` command tree.

    **Usage:**
        - Using the ``.query()`` method will send the ``CONNected:REQUested?`` query.
        - Using the ``.verify(value)`` method will send the ``CONNected:REQUested?`` query and raise
          an AssertionError if the returned value does not match ``value``.

    Properties:
        - ``.status``: The ``CONNected:REQUested:STATus`` command.
    """

    def __init__(self, device: Optional["PIDevice"], cmd_syntax: str) -> None:
        super().__init__(device, cmd_syntax)
        self._status = ConnectedRequestedStatus(device, f"{self._cmd_syntax}:STATus")

    @property
    def status(self) -> ConnectedRequestedStatus:
        """Return the ``CONNected:REQUested:STATus`` command.

        **Description:**
            - This command sets the status of the Connected Scope Preference feature. After issuing
              the status command, the ``CONNected:SAVEPREferences`` command should be set
              immediately to make the feature enabled. On the instrument, the feature is found in
              Utility > User Preferences > Other > Connected Scope Preferences.

        **Usage:**
            - Using the ``.write(value)`` method will send the ``CONNected:REQUested:STATus value``
              command.

        **SCPI Syntax:**

        ::

            - CONNected:REQUested:STATus <NR1>

        **Info:**
            - ``<NR1>`` enables or disables the Connected Scope Preference feature. The argument can
              be either 1 or 0. Setting 1 will enable the feature.
        """
        return self._status


class Connected(SCPICmdRead):
    """The ``CONNected`` command tree.

    **Usage:**
        - Using the ``.query()`` method will send the ``CONNected?`` query.
        - Using the ``.verify(value)`` method will send the ``CONNected?`` query and raise an
          AssertionError if the returned value does not match ``value``.

    Properties:
        - ``.requested``: The ``CONNected:REQUested`` command tree.
        - ``.status``: The ``CONNected:STATus`` command.
        - ``.usage``: The ``CONNected:USAGe`` command tree.
    """

    def __init__(self, device: Optional["PIDevice"] = None, cmd_syntax: str = "CONNected") -> None:
        super().__init__(device, cmd_syntax)
        self._requested = ConnectedRequested(device, f"{self._cmd_syntax}:REQUested")
        self._status = ConnectedStatus(device, f"{self._cmd_syntax}:STATus")
        self._usage = ConnectedUsage(device, f"{self._cmd_syntax}:USAGe")

    @property
    def requested(self) -> ConnectedRequested:
        """Return the ``CONNected:REQUested`` command tree.

        **Usage:**
            - Using the ``.query()`` method will send the ``CONNected:REQUested?`` query.
            - Using the ``.verify(value)`` method will send the ``CONNected:REQUested?`` query and
              raise an AssertionError if the returned value does not match ``value``.

        Sub-properties:
            - ``.status``: The ``CONNected:REQUested:STATus`` command.
        """
        return self._requested

    @property
    def status(self) -> ConnectedStatus:
        """Return the ``CONNected:STATus`` command.

        **Description:**
            - This query command returns the status of the Connected Scope Preference feature. On
              the instrument, the feature is found in Utility > User Preferences > Other > Connected
              Scope Preferences.

        **Usage:**
            - Using the ``.query()`` method will send the ``CONNected:STATus?`` query.
            - Using the ``.verify(value)`` method will send the ``CONNected:STATus?`` query and
              raise an AssertionError if the returned value does not match ``value``.

        **SCPI Syntax:**

        ::

            - CONNected:STATus?
        """
        return self._status

    @property
    def usage(self) -> ConnectedUsage:
        """Return the ``CONNected:USAGe`` command tree.

        **Usage:**
            - Using the ``.query()`` method will send the ``CONNected:USAGe?`` query.
            - Using the ``.verify(value)`` method will send the ``CONNected:USAGe?`` query and raise
              an AssertionError if the returned value does not match ``value``.

        Sub-properties:
            - ``.track``: The ``CONNected:USAGe:TRack`` command tree.
        """
        return self._usage



"""MSO4B device driver module."""
from tm_devices.commands import MSO4BMixin
from tm_devices.drivers.pi.scopes.tekscope.mso4 import MSO4


class MSO4B(MSO4BMixin, MSO4):
    """MSO4B device driver."""



"""The status_and_error commands module.

These commands are used in the following models:
DPO5KB, DPO70KC, DPO70KD, DPO70KDX, DPO70KSX, DPO7KC, DSA70KC, DSA70KD, LPD6, MSO2, MSO4, MSO4B,
MSO5, MSO5B, MSO5KB, MSO5LP, MSO6, MSO6B, MSO70KC, MSO70KDX

THIS FILE IS AUTO-GENERATED, IT SHOULD NOT BE MANUALLY MODIFIED.

Please report an issue if one is found.

Commands and Queries:

::

    - *PSC {<NR1>|OFF|ON}
    - *PSC?
"""
from typing import Optional, TYPE_CHECKING

from .._helpers import SCPICmdRead, SCPICmdWrite

if TYPE_CHECKING:
    from tm_devices.drivers.pi.pi_device import PIDevice


class Psc(SCPICmdWrite, SCPICmdRead):
    """The ``*PSC`` command.

    **Description:**
        - This command sets and queries the power-on status flag that controls the automatic
          power-on handling of the DESER, SRER, and ESER registers. When ``*PSC`` is true, the DESER
          register is set to 255 and the SRER and ESER registers are set to 0 at power-on. When
          ``*PSC`` is false, the current values in the DESER, SRER, and ESER registers are preserved
          in nonvolatile memory when power is shut off and are restored at power-on.

    **Usage:**
        - Using the ``.query()`` method will send the ``*PSC?`` query.
        - Using the ``.verify(value)`` method will send the ``*PSC?`` query and raise an
          AssertionError if the returned value does not match ``value``.
        - Using the ``.write(value)`` method will send the ``*PSC value`` command.

    **SCPI Syntax:**

    ::

        - *PSC {<NR1>|OFF|ON}
        - *PSC?

    **Info:**
        - ``<NR1>`` = 0 sets the power-on status clear flag to false, disables the power-on clear
          and allows the instrument to possibly assert SRQ after power-on; any other value sets the
          power-on status clear flag to true, enabling the power-on status clear and prevents any
          SRQ assertion after power on.
        - ``OFF`` sets the power-on status clear flag to false, disables the power-on clear and
          allows the instrument to possibly assert SRQ after power-on.
        - ``ON`` sets the power-on status clear flag to true, enabling the power-on status clear and
          prevents any SRQ assertion after power on.
    """

    def __init__(self, device: Optional["PIDevice"] = None, cmd_syntax: str = "*PSC") -> None:
        super().__init__(device, cmd_syntax)



"""The status_and_error commands module.

These commands are used in the following models:
AFG3K, AFG3KB, AFG3KC, AWG5200, AWG5K, AWG5KC, AWG70KA, AWG70KB, AWG7K, AWG7KC, DPO2K, DPO2KB,
DPO4K, DPO4KB, DPO5KB, DPO70KC, DPO70KD, DPO70KDX, DPO70KSX, DPO7KC, DSA70KC, DSA70KD, LPD6, MDO3,
MDO3K, MDO4K, MDO4KB, MDO4KC, MSO2, MSO2K, MSO2KB, MSO4, MSO4B, MSO4K, MSO4KB, MSO5, MSO5B, MSO5KB,
MSO5LP, MSO6, MSO6B, MSO70KC, MSO70KDX

THIS FILE IS AUTO-GENERATED, IT SHOULD NOT BE MANUALLY MODIFIED.

Please report an issue if one is found.

Commands and Queries:

::

    - *CLS
    - *ESR?
    - *OPC
    - *OPC?
    - *RST
    - *STB?
    - *WAI
"""
from typing import Optional, TYPE_CHECKING

from .._helpers import SCPICmdRead, SCPICmdWriteNoArguments

if TYPE_CHECKING:
    from tm_devices.drivers.pi.pi_device import PIDevice


class Wai(SCPICmdWriteNoArguments):
    """The ``*WAI`` command.

    **Description:**
        - The ``*WAI`` (Wait) command (no query form) prevents the instrument from executing further
          commands or queries until all pending commands that generate an OPC message are complete.
          This command allows you to synchronize the operation of the instrument with your
          application program. For more information, refer to Synchronization Methods.

    **Usage:**
        - Using the ``.write()`` method will send the ``*WAI`` command.

    **SCPI Syntax:**

    ::

        - *WAI
    """

    def __init__(self, device: Optional["PIDevice"] = None, cmd_syntax: str = "*WAI") -> None:
        super().__init__(device, cmd_syntax)


class Stb(SCPICmdRead):
    """The ``*STB`` command.

    **Description:**
        - The ``*STB?`` (Read Status Byte) query returns the contents of the Status Byte Register
          (SBR) using the Master Summary Status (MSS) bit. For more information, refer to Registers.

    **Usage:**
        - Using the ``.query()`` method will send the ``*STB?`` query.
        - Using the ``.verify(value)`` method will send the ``*STB?`` query and raise an
          AssertionError if the returned value does not match ``value``.

    **SCPI Syntax:**

    ::

        - *STB?
    """

    def __init__(self, device: Optional["PIDevice"] = None, cmd_syntax: str = "*STB") -> None:
        super().__init__(device, cmd_syntax)


class Rst(SCPICmdWriteNoArguments):
    """The ``*RST`` command.

    **Description:**
        - This command (no query form) resets the instrument to the factory default settings. This
          command does the following: Recalls the default instrument setup. Clears the current
          ``*DDT`` command. Disables aliases (``:ALIAS:STATE 0``). Disables the user password (for
          the ``*PUD`` command). The ``*RST`` command does not change the following: The current
          working directory ( ``:FILESystem:CWD`` command). The state of command headers (
          ``:HEADer`` command). The state of keyword and enumeration verbosity ( ``:VERBose``
          command). The Power-on Status Clear Flag ( ``*PSC`` command). The Event Status Enable
          Register ( ``*ESE`` command). The Service Request Enable Register ( ``*SRE`` command). The
          Device Event Status Enable Register ( DESE command). The user password for protected user
          data ( ``:PASSWord`` command). The content of protected user data ( ``*PUD`` command). The
          enabled state of the socket server ( ``:SOCKETServer:ENAble`` command). The socket server
          port number ( ``:SOCKETServer:PORT`` command). The socket server protocol (
          ``:SOCKETServer:PROTOCol`` command). The USBTMC port configuration (
          ``:USBDevice:CONFigure`` command). The destination reference waveform or file path for the
          ``:CURVe`` command ( ``:DATa:DESTination`` command). The source waveform for the
          ``:CURVe?`` or ``:WAVFrm?`` queries ( ``:DATa:SOUrce`` command). The waveform data
          encoding for the ``:CURVe`` command or query or the ``:WAVFrm?`` query ( ``:DATa:ENCdg``
          command). The starting point for ``:CURVe?`` queries ( ``:DATa:STARt`` command). The
          ending point for ``:CURVe?`` queries ( ``:DATa:STOP`` command). All settings associated
          the ``:WFMInpre`` commands. All user settable settings associated with the WFMOutpre
          commands. ``*RST`` only resets the programmable interface settings, it does not change the
          user interface settings.

    **Usage:**
        - Using the ``.write()`` method will send the ``*RST`` command.

    **SCPI Syntax:**

    ::

        - *RST
    """

    def __init__(self, device: Optional["PIDevice"] = None, cmd_syntax: str = "*RST") -> None:
        super().__init__(device, cmd_syntax)


class Opc(SCPICmdWriteNoArguments, SCPICmdRead):
    """The ``*OPC`` command.

    **Description:**
        - This command generates the operation complete message in the Standard Event Status
          Register (SESR) when all pending commands that generate an OPC message are complete. The
          ``*OPC?`` query places the ASCII character '1' into the output queue when all such OPC
          commands are complete. The ``*OPC?`` response is not available to read until all pending
          operations finish. For a complete discussion of the use of these registers and the output
          queue, see Registers and Queues. The ``*OPC`` command allows you to synchronize the
          operation of the instrument with your application program. For more information, see
          Synchronization Methods. Refer to the Oscilloscope operations that can generate OPC table
          for a list of commands that generate an OPC message.

    **Usage:**
        - Using the ``.query()`` method will send the ``*OPC?`` query.
        - Using the ``.verify(value)`` method will send the ``*OPC?`` query and raise an
          AssertionError if the returned value does not match ``value``.
        - Using the ``.write()`` method will send the ``*OPC`` command.

    **SCPI Syntax:**

    ::

        - *OPC
        - *OPC?
    """

    def __init__(self, device: Optional["PIDevice"] = None, cmd_syntax: str = "*OPC") -> None:
        super().__init__(device, cmd_syntax)


class Esr(SCPICmdRead):
    """The ``*ESR`` command.

    **Description:**
        - This query-only command returns the contents of the Standard Event Status Register (SESR).
          ``*ESR?`` also clears the SESR (since reading the SESR clears it). For a more detailed
          discussion of the use of these registers, see Registers.

    **Usage:**
        - Using the ``.query()`` method will send the ``*ESR?`` query.
        - Using the ``.verify(value)`` method will send the ``*ESR?`` query and raise an
          AssertionError if the returned value does not match ``value``.

    **SCPI Syntax:**

    ::

        - *ESR?
    """

    def __init__(self, device: Optional["PIDevice"] = None, cmd_syntax: str = "*ESR") -> None:
        super().__init__(device, cmd_syntax)


class Cls(SCPICmdWriteNoArguments):
    """The ``*CLS`` command.

    **Description:**
        - This command (no query form) clears the following: Event Queue Standard Event Status
          Register Status Byte Register (except the MAV bit) If the ``*CLS`` command immediately
          follows an <EOI>, the Output Queue and MAV bit (Status Byte Register bit 4) are also
          cleared. MAV indicates that information is in the output queue. The device clear (DCL)
          control message will clear the output queue and thus MAV. ``*CLS`` does not clear the
          output queue or MAV. ``*CLS`` can suppress a Service Request that is to be generated by an
          ``*OPC``. This will happen if a single sequence acquisition operation is still being
          processed when the ``*CLS`` command is executed.

    **Usage:**
        - Using the ``.write()`` method will send the ``*CLS`` command.

    **SCPI Syntax:**

    ::

        - *CLS
    """

    def __init__(self, device: Optional["PIDevice"] = None, cmd_syntax: str = "*CLS") -> None:
        super().__init__(device, cmd_syntax)



"""The pilogger commands module.

These commands are used in the following models:
LPD6, MSO4, MSO4B, MSO5, MSO5B, MSO5LP, MSO6, MSO6B

THIS FILE IS AUTO-GENERATED, IT SHOULD NOT BE MANUALLY MODIFIED.

Please report an issue if one is found.

Commands and Queries:

::

    - PILOGger:FILEName <QString>
    - PILOGger:FILEName?
    - PILOGger:STATE {<NR1>|OFF|ON}
    - PILOGger:STATE?
"""
from typing import Optional, TYPE_CHECKING

from .._helpers import SCPICmdRead, SCPICmdWrite

if TYPE_CHECKING:
    from tm_devices.drivers.pi.pi_device import PIDevice


class PiloggerState(SCPICmdWrite, SCPICmdRead):
    """The ``PILOGger:STATE`` command.

    **Description:**
        - This command sets or queries the state of the programmatic interface command log. If the
          location specified by ``PILOGGER:FILENAME`` does not exist or is not writable, attempts to
          turn the PI command logger ON will fail, and the state will be set to 0 (OFF).

    **Usage:**
        - Using the ``.query()`` method will send the ``PILOGger:STATE?`` query.
        - Using the ``.verify(value)`` method will send the ``PILOGger:STATE?`` query and raise an
          AssertionError if the returned value does not match ``value``.
        - Using the ``.write(value)`` method will send the ``PILOGger:STATE value`` command.

    **SCPI Syntax:**

    ::

        - PILOGger:STATE {<NR1>|OFF|ON}
        - PILOGger:STATE?

    **Info:**
        - ``<NR1>`` = 0 disables the PI command logger; any other value turns the PI command logger
          on.
        - ``OFF`` disables the PI command logger.
        - ``ON`` enables the PI command logger.
    """


class PiloggerFilename(SCPICmdWrite, SCPICmdRead):
    """The ``PILOGger:FILEName`` command.

    **Description:**
        - This command sets or queries the location where the programmatic interface command log
          will be saved.

    **Usage:**
        - Using the ``.query()`` method will send the ``PILOGger:FILEName?`` query.
        - Using the ``.verify(value)`` method will send the ``PILOGger:FILEName?`` query and raise
          an AssertionError if the returned value does not match ``value``.
        - Using the ``.write(value)`` method will send the ``PILOGger:FILEName value`` command.

    **SCPI Syntax:**

    ::

        - PILOGger:FILEName <QString>
        - PILOGger:FILEName?

    **Info:**
        - ``<QString>`` is a quoted string that defines the file path that specifies the location to
          save the command log, in the format '[<path>]<filename.ext>'. Specifying a path is
          optional. If no path is entered, the instrument will search in the current working
          directory as set in ``FILESYSTEM:CWD``.
    """

    _WRAP_ARG_WITH_QUOTES = True


class Pilogger(SCPICmdRead):
    """The ``PILOGger`` command tree.

    **Usage:**
        - Using the ``.query()`` method will send the ``PILOGger?`` query.
        - Using the ``.verify(value)`` method will send the ``PILOGger?`` query and raise an
          AssertionError if the returned value does not match ``value``.

    Properties:
        - ``.filename``: The ``PILOGger:FILEName`` command.
        - ``.state``: The ``PILOGger:STATE`` command.
    """

    def __init__(self, device: Optional["PIDevice"] = None, cmd_syntax: str = "PILOGger") -> None:
        super().__init__(device, cmd_syntax)
        self._filename = PiloggerFilename(device, f"{self._cmd_syntax}:FILEName")
        self._state = PiloggerState(device, f"{self._cmd_syntax}:STATE")

    @property
    def filename(self) -> PiloggerFilename:
        """Return the ``PILOGger:FILEName`` command.

        **Description:**
            - This command sets or queries the location where the programmatic interface command log
              will be saved.

        **Usage:**
            - Using the ``.query()`` method will send the ``PILOGger:FILEName?`` query.
            - Using the ``.verify(value)`` method will send the ``PILOGger:FILEName?`` query and
              raise an AssertionError if the returned value does not match ``value``.
            - Using the ``.write(value)`` method will send the ``PILOGger:FILEName value`` command.

        **SCPI Syntax:**

        ::

            - PILOGger:FILEName <QString>
            - PILOGger:FILEName?

        **Info:**
            - ``<QString>`` is a quoted string that defines the file path that specifies the
              location to save the command log, in the format '[<path>]<filename.ext>'. Specifying a
              path is optional. If no path is entered, the instrument will search in the current
              working directory as set in ``FILESYSTEM:CWD``.
        """
        return self._filename

    @property
    def state(self) -> PiloggerState:
        """Return the ``PILOGger:STATE`` command.

        **Description:**
            - This command sets or queries the state of the programmatic interface command log. If
              the location specified by ``PILOGGER:FILENAME`` does not exist or is not writable,
              attempts to turn the PI command logger ON will fail, and the state will be set to 0
              (OFF).

        **Usage:**
            - Using the ``.query()`` method will send the ``PILOGger:STATE?`` query.
            - Using the ``.verify(value)`` method will send the ``PILOGger:STATE?`` query and raise
              an AssertionError if the returned value does not match ``value``.
            - Using the ``.write(value)`` method will send the ``PILOGger:STATE value`` command.

        **SCPI Syntax:**

        ::

            - PILOGger:STATE {<NR1>|OFF|ON}
            - PILOGger:STATE?

        **Info:**
            - ``<NR1>`` = 0 disables the PI command logger; any other value turns the PI command
              logger on.
            - ``OFF`` disables the PI command logger.
            - ``ON`` enables the PI command logger.
        """
        return self._state
